Footnotes — Askbot v0.7.43 documentation

# Askbot Project Documentation

Home | Ask Questions | Hire Us | Documentation | Contribute | Contact

# Footnotes

This page summarizes additional information that might be useful for deployment of development of `askbot`.

## Git

At askbot we use `git` to keep track of the source code, and the main repository is hosted at github.

With git you can always grab the latest code of askbot from the latest `askbot` code:

    git clone git://github.com/ASKBOT/askbot-devel.git

Do some customization by editing files and then:

    git add <list-of-changed-files>
    git commit -m 'explain why you have changed some files'

Bring updates from the main repo:

    git git fetch origin master:github #.. onto a local branch called github
    git checkout master
    git merge github

If all goes well, you are done. Otherwise, you may need to resolve the conflict.

Here is a good basic tutorial about git, more comprehensive ones here and there. Finally, you also may want to visit the official git reference and documentation. There are screencasts too.

## Pip

`Pip` is the best package management tool for python, allows to install and unistall python packages, supports installation from source code repositories and much more.

For more information about `pip`, including its installation, please visit the pip package page and the links within.